#file-label {
    font-size: 1.5em;
    line-height: 2em;
    text-decoration: none;
    display: block;
}

#file-label:hover {
    cursor: pointer;
    text-decoration: underline;
}

.footer {
    color: #666;
    font-size: 80%;
    padding: 1em;
    text-align: center;
    width: auto;

}

.footer a {
    color: #666;
}

.footer-home {
    color: #fff;
    font-size: 1em;
    margin-top: 40px;
    padding: 1em;
    text-align: center;
    width: 100%;
    font-family: Helvetica, sans-serif;
    font-weight: 100;
}

.footer-home a {
    color: #fff;
}

.header {
    /*border-bottom: 1px solid #eee;*/
    color: #333;
    margin: 0;
    padding: 0 2em 0;
    text-align: center;
}

.header h1 {
    font-size: 2em;
    font-weight: 300;
    margin: 0;
}

.header h2 {
    color: grey;
    font-size: 1.3em;
    font-weight: 300;
    margin-top: 1em;
    padding: 0;
}

.recent-xminds tr:hover td {
    background-color: rgba(255, 255, 255, 0.3);
}

.select-xmind {
    border-bottom: 2px solid #FFF;
    margin: auto;
    padding-bottom: 2em;
    width: 60%;

}

.splash {
    height: 60%;
    margin: auto;
    position: relative;
    text-align: center;
    width: 80%;
    margin-top: 8%;
}

.splash-container {
    background: #00b36b;
    height: 100%;
    overflow: hidden;
    position: fixed !important;
    top: 0;
    left: 0;
    width: 100%;
    z-index: 1;
    text-shadow: 1px 1px 5px rgba(0, 0, 0, 0.3);
}

.splash-container h1 {
    color: #fff;
    font-size: 3em;
    font-weight: 600;
    margin-bottom: 1em;
    text-align: center;
    text-shadow: 5px 5px 11px rgba(0, 0, 0, 0.58);
    text-transform: uppercase;
}

.splash-head {
    box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.2);
    color: #FFF;
    padding: 1.5em 1.6em;
}

.splash-head p {
    color: #FFF;
    font-size: .9em;
    letter-spacing: .05em;
    opacity: 0.9;
}

.splash-subhead {
    color: #FFF;
    letter-spacing: .05em;
    opacity: 0.9;
}

.tag-error {
    background: #ca3c3c;
}

.tag-info {
    background: #42b8dd;
}

.tag-success {
    background: #1cb841;
}

.tag-success, .tag-error, .tag-warn, .tag-info {
    border-radius: 3px;
    color: #FFF;
    font-size: .8em;
    padding: 4px;
    text-shadow: 0 1px 1px rgba(0, 0, 0, 0.2);
}

.tag-warn {
    background: #df7514;
}

.tests-table tr:hover td {
    background-color: #f2f3f4;
}

.tooltip {
    display: inline-block;
    position: relative;
}

.tooltip .tooltiptext {
    background-color: #000;
    border-radius: 4px;
    color: #fff;
    max-width: 400px;
    min-width: 60px;
    padding: 6px;
    position: absolute;
    text-align: left;
    visibility: hidden;
    white-space: normal;
    width: max-content;
    width: -moz-max-content;
    word-break: normal;
    word-wrap: break-word;
    z-index: 1;
}

.tooltip:hover .tooltiptext {
    visibility: visible;
}

a {
    color: #3d92c9;
    text-decoration: none;
}

a:hover, a:focus {
    text-decoration: underline;
}

body {
    padding: 30px;
    font-family: Tahoma, Geneva, "Microsoft YaHei", sans-serif;
}

input[type="file"] {
    /*display: none;*/
    opacity: 0;
}

input[type="submit"] {
    font-size: 1.2em;
}

input[type="submit"]:hover {
    box-shadow: 0 0 6px rgba(35, 173, 255, 1);
}

ol {
    margin-bottom: 0;
    margin-left: -20px;
    margin-top: 0;
}

ol ul {
    margin-left: -30px;
}

table.recent-xminds {
    font-size: 0.8em;
    margin-top: 2em;
    width: 100%;
    font-family: 'Open Sans', sans-serif;
}

table.recent-xminds a {
    color: #fff;
    text-decoration: underline;
}

table.recent-xminds td:nth-child(1) {
    text-align: left;
}

table.recent-xminds th {
    background-color: #f2f3f4;
    text-align: center;
}

table.tests-table {
    font-size: .8em;
    margin-bottom: 2em;
    margin-top: 2em;
    width: 100%;
}

table.tests-table tr td {
    border-bottom: #cbcbcb solid 1px;
}

table.tests-table tr th {
    background-color: #444;
    color: #fff;
    height: 2em;
    vertical-align: middle;
}

table td.long-name {
    color: red
}

.long-name-info {
    background-color: #000;
    border-radius: 4px;
    color: #fff;
    max-width: 400px;
    min-width: 60px;
    padding: 6px;
    position: absolute;
    text-align: left;
    visibility: hidden;
    white-space: normal;
    width: max-content;
    width: -moz-max-content;
    word-break: normal;
    word-wrap: break-word;
    z-index: 1;
}

table td.long-name:hover .long-name-info {
    visibility: visible;
}