__title__ = "xmind2testcasezen"
__description__ = "XMind2TestCaseZen基于XMind2TestCase做二次开发，提供了一个高效测试用例设计的解决方案！"
__keywords__ = ["xmind2testCase, testcase, test, testing, xmind, 思维导图, XMind思维导图"]
__url__ = "https://github.com/maiyajj/xmind2testcasezen"
__author__ = "maiyajj"
__author_email__ = ""
__version__ = "0.0.3"
__license__ = "MIT"
